if (app.documents.length > 0 && app.activeDocument.selection.length > 0) {
  var doc = app.activeDocument;
  var sel = app.activeDocument.selection;
  var textItems = [];

  // テキストフレームだけ抽出
  for (var i = 0; i < sel.length; i++) {
    if (sel[i].typename === "TextFrame") {
      textItems.push(sel[i]);
    }
  }

  if (textItems.length === 0) {
    var msgNone = "テキストオブジェクトが選択されていません。";
    alert(msgNone);
  } else {
    // スペースを除外するかどうかの確認ダイアログ
    var confirmMsg = "結合の語間のスペースを除外しますか？";
    var removeSpace = confirm(confirmMsg);

    // 結合順序は top > left
    textItems.sort(function(a, b) {
      return b.top !== a.top ? b.top - a.top : a.left - b.left;
    });

    var reference = textItems[0];
    var orientation = reference.orientation;
    var layer = reference.layer;
    var attr = reference.textRange.characterAttributes;

    // 1行に結合（スペース or 無し）
    var combinedText = "";
    for (var j = 0; j < textItems.length; j++) {
      combinedText += textItems[j].contents;
      if (j !== textItems.length - 1 && !removeSpace) {
        combinedText += " ";
      }
    }

    // 新しいテキストフレーム作成
    var newText = layer.textFrames.add();
    newText.contents = combinedText;
    newText.orientation = orientation;

    // スタイル継承
    var newAttr = newText.textRange.characterAttributes;
    newAttr.textFont = attr.textFont;
    newAttr.size = attr.size;
    newAttr.fillColor = attr.fillColor;
    newAttr.tracking = attr.tracking;
    newAttr.baselineShift = attr.baselineShift;

    // 基点復元処理
    var baseItem = textItems[0];
    if (orientation === TextOrientation.HORIZONTAL) {
      for (var i = 1; i < textItems.length; i++) {
        if (textItems[i].left < baseItem.left) {
          baseItem = textItems[i];
        }
      }
    } else {
      for (var i = 1; i < textItems.length; i++) {
        if (textItems[i].top > baseItem.top) {
          baseItem = textItems[i];
        }
      }
    }

    // 位置をその基点に移動
    newText.position = baseItem.position;

    // 元オブジェクト削除
    for (var k = 0; k < textItems.length; k++) {
      textItems[k].remove();
    }

    var msgDone = "1行に結合しました。";
    alert(msgDone);
  }
} else {
  var msgSelect = "ポイントテキストを選択してください。";
  alert(msgSelect);
}
